Client Reference — BAM - Blender Asset Manager 0.0.1 alpha documentation

# Client Reference

Here is a reference of all the BAM cli commands.

BAM! Blender asset manager

    usage: bam [-h]
               {init,create,cr,checkout,co,commit,ci,update,up,revert,rv,status,st,list,ls,deps,dp,pack,pk,remap}
               ...

Sub-commands:
  init

    Initialize a new project directory

        usage: bam init [-h] url [directory_name]

    Positional arguments:

      `url` | Project repository url
      `directory_name` | Directory name

  create (cr)

    Create a new empty session directory

        usage: bam create [-h] session_name

    Positional arguments:

      `session_name` | Name of session directory

  checkout (co)

    Checkout a remote path in an existing project

        usage: bam checkout [-h] [-o DIRNAME] [-a] REMOTE_PATH

    Positional arguments:

      `path` | Path to checkout on the server

    Options:

      `-o, --output` | Local name to checkout the session into (optional, falls back to path name)
      `-a=False, --all-deps=False`
      | Follow all dependencies (unused indirect dependencies too)

  commit (ci)

    Commit changes from a session to the remote project

        usage: bam commit [-h] -m MESSAGE [paths [paths ...]]

    Positional arguments:

      `paths` | paths to commit

    Options:

      `-m, --message` | Commit message

  update (up)

    Update a local session with changes from the remote project

        usage: bam update [-h] [paths [paths ...]]

    Positional arguments:

      `paths` | Path(s) to operate on

  revert (rv)

    Reset local changes back to the state at time of checkout

        usage: bam revert [-h] paths [paths ...]

    Positional arguments:

      `paths` | Path(s) to operate on

  status (st)

    Show any edits made in the local session

        usage: bam status [-h] [-j] [paths [paths ...]]

    Positional arguments:

      `paths` | Path(s) to operate on

    Options:

      `-j=False, --json=False`
      | Generate JSON output

  list (ls)

    List the contents of a remote directory

        usage: bam list [-h] [-j] [paths [paths ...]]

    Positional arguments:

      `paths` | Path(s) to operate on

    Options:

      `-j=False, --json=False`
      | Generate JSON output

  deps (dp)

    List dependencies for file(s)

        usage: bam deps [-h] [-r] [-j] [paths [paths ...]]

    Positional arguments:

      `paths` | Path(s) to operate on

    Options:

      `-r=False, --recursive=False`
      | Scan dependencies recursively
      `-j=False, --json=False`
      | Generate JSON output

  pack (pk)

    Pack a blend file and its dependencies into an archive

        usage: bam pack [-h] -o ZIP [-a] [-q] [-c LEVEL] paths [paths ...]

    Positional arguments:

      `paths` | Path(s) to operate on

    Options:

      `-o, --output` | Output file or a directory when multiple inputs are passed
      `-a=False, --all-deps=False`
      | Follow all dependencies (unused indirect dependencies too)
      `-q=False, --quiet=False`
      | Suppress status output
      `-c=default, --compress=default`
      | Compression level for resulting archive Possible choices: default, fast, best, store

  remap

    Remap blend file paths

        usage: bam remap [-h] {start,finish,reset} ...